@@ -1,12 +1,12 @@
-import datetime as DT 
+import datetime as DT
 
 MAJOR_VERSION = 0
 '''Major version number'''
 
-MINOR_VERSION = 3
+MINOR_VERSION = 4
 '''Minor version number'''
 
-REVISION_VERSION = 16
+REVISION_VERSION = 3
 '''Revision version number'''
 
 VERSION = (MAJOR_VERSION,MINOR_VERSION,REVISION_VERSION)
@@ -18,5 +18,11 @@ __version__ = '{0:d}.{1:d}.{2:d}'.format(*VERSION)
 __ver__ = '{0:d}.{1:d}'.format(*VERSION)
 '''DAPI2 library DAPI2 short version (str)'''
 
-DATE = DT.date(2022, 8, 22)
-'''Release date'''
\ No newline at end of file
+DATE = DT.date(2022, 11, 11)
+'''Release date'''
+
+__date__ = DATE.isoformat()
+'''Release date string in ISO format'''
+
+REQUIRED_PYTHON = (3,8)
+'''The required Python verison'''
\ No newline at end of file
