@@ -219,16 +219,23 @@ class DApiAccessLevel(DIntEnum):
 class DApiAdditionalBoard(DIntEnum):
     '''Enumeration for DAPI2 access level'''
     NO = 0
-    AB12 = 1
-    AB03 = 2
+    AB14 = 1
+    AB12 = 2
+    AB1214 = 3
+    AB03 = 4
+    AB0314 = 5
+    
     
     @property
     def descr(self):
         '''Label according access level'''
         return {
             self.NO : 'No',
+            self.AB14 : 'AB-14',
             self.AB12 : 'AB-12',
+            self.AB1214 : 'AB-12+AB-14',
             self.AB03 : 'AB-03',
+            self.AB0314 : 'AB-03+AB-14',
             }[self]    
 
     @property
@@ -236,8 +243,11 @@ class DApiAdditionalBoard(DIntEnum):
         '''Help message according access level'''
         return {
             self.NO : 'No additional board is present.',
+            self.AB14 : 'DIP switches board (AB-14) is present',
             self.AB12 : 'Auxiliary inputs board (AB-12) is present.',
-            self.AB03 : 'Dual lighting (AB-03) is present.',
+            self.AB1214 : 'Auxiliary inputs board (AB-12) and DIP switches (AB-14) are present.',
+            self.AB03 : 'Dual lighting (AB-03) and DIP switches (AB-14) are present.',
+            self.AB0314 : 'AB-03+AB-14',
             }[self]    
         
 class MetaDApi2Commands(object):
