@@ -26,9 +26,14 @@ class DacChannel(IntEnum):
     DAC0 = 0
     DAC1 = 1
 
-class DacSignal(IntEnum):
-    pass
 
+class DacSignal(IntEnum):
+    DPA_VIRT = 0
+    DPA_REAL = 1
+    PHI = 2
+    DRAG = 3
+    PWM_OPENING = 4
+    
 
 class WorkspaceChangedSignal(DSignal):
     
@@ -63,6 +68,8 @@ class BaseDBoard(object):
     wait_after_reboot = 2.0 #[s]
     '''Timeout after reboot to reconnect to the board expressed in second.'''
     
+    DAC_SIGNAL = DacSignal
+    
     @classmethod
     def getBoardClasses(cls):
         '''Returns all known board classes
@@ -389,10 +396,15 @@ class BaseDBoard(object):
             self._dapi.readReg(self.regs.scsr)
         return LastReset(self.regs.scsr.bits.reset.value)
 
-    def getWatchdog(self, refresh=False):
+    def getPeripheralWatchdog(self, refresh=False):
         if refresh:
             self._dapi.readReg(self.regs.scsr)
-        return self.regs.scsr.bits.watchdog.value != 0
+        return self.regs.scsr.bits.pwd.value != 0
+
+    def getIndependentWatchdog(self, refresh=False):
+        if refresh:
+            self._dapi.readReg(self.regs.scsr)
+        return self.regs.scsr.bits.iwd.value != 0
 
     
     def getSystemModeConfiguration(self, refresh=False):
@@ -770,28 +782,28 @@ class BaseDBoard(object):
     def eepromReset(self):
         self._dapi.cmd.factEerpomReset()
         
-    def flashFirm(self, firm, callback=None):
+    def flashBinaryFirm(self, stream, callback=None):
         
         def _readByte(x):
-            c = f.read(1)
+            c = stream.read(1)
             if c == '':
                 return 0
             else:
                 return ord(c)
         self.log.info('Firmware programming has started....')
-        with open( firm, 'rb' ) as f:
-            f.seek(0, os.SEEK_END)
-            size = f.tell()
-            self._dapi.cmd.flashBegin(size)
-            f.seek(0)
-            i = 0
-            
-            while i < size:
-                self._dapi.cmd.flashData([_readByte(x) for x in range(CommandMessage.MAX_DATA_SIZE)])
-                i+=CommandMessage.MAX_DATA_SIZE
-                self.log.debug('Programming block {0} / {1}'.format(i//CommandMessage.MAX_DATA_SIZE,size//CommandMessage.MAX_DATA_SIZE))
-                if callback is not None:
-                    callback(i, size)
+        #with open( firm, 'rb' ) as f:
+        stream.seek(0, os.SEEK_END)
+        size = stream.tell()
+        self._dapi.cmd.flashBegin(size)
+        stream.seek(0)
+        i = 0
+        
+        while i < size:
+            self._dapi.cmd.flashData([_readByte(x) for x in range(CommandMessage.MAX_DATA_SIZE)])
+            i+=CommandMessage.MAX_DATA_SIZE
+            #self.log.debug('Programming block {0} / {1}'.format(i//CommandMessage.MAX_DATA_SIZE,size//CommandMessage.MAX_DATA_SIZE))
+            if callback is not None:
+                callback(i, size)
                     
 
         self._dapi.cmd.flashEnd()
@@ -884,9 +896,14 @@ class DBoard(BaseDBoard):
                     PowerSupply(self),)
                     )
             )
-        self._debug_values = ( DebugValue(self, i) for i in range(self.regs.dmr.size) )
-        
+        self._debug_values = [ DebugValue(self, self.regs.dmr[i]) for i in range(self.regs.dmr.size) ] 
+        self._debug_setting_values = [ DebugValue(self, self.regs.dsr[i]) for i in range(self.regs.dsr.size) ]
         
     @property
     def debugValues(self):
-        return self._debug_values
\ No newline at end of file
+        return self._debug_values
+    @property
+    def debugSettingValues(self):
+        return self._debug_setting_values    
+    
+    
\ No newline at end of file
