@@ -4,17 +4,8 @@
 :date: 2021-02-24 Creation
 '''
 
-from .base import DBoard, DBoardPreferredDapiMode, DacSignal
- 
 
-
-class DacSignalMb30(DacSignal):
-    DPA_VIRT = 0
-    DPA_REAP = 1
-    PHI = 2
-    DRAG = 3
-    PWM_OPENING = 4
-    
+from .base import DBoard, DBoardPreferredDapiMode
 
 class Board30(DBoard):
     '''Class for MB-30 Dassym's board.
@@ -27,8 +18,6 @@ class Board30(DBoard):
     number = '30'
     '''Board type number (str)'''
     
-    DAC_SIGNAL = DacSignalMb30
-
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
         super().__init__(dapi, dmode)
