@@ -3,16 +3,8 @@
 :author: F. Voillat
 :date: 2021-02-24 Creation
 '''
-from .base import DBoard, DacSignal, DBoardPreferredDapiMode
+from .base import DBoard, DBoardPreferredDapiMode
 
-
-class DacSignalMb60(DacSignal):
-    DPA_VIRT = 0
-    DPA_REAP = 1
-    PHI = 2
-    DRAG = 3
-    PWM_OPENING = 4
-    
     
 
 class Board60(DBoard):
@@ -26,7 +18,7 @@ class Board60(DBoard):
     number = '60'
     '''Board type number (str)'''
     
-    DAC_SIGNAL = DacSignalMb60
+
 
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
