@@ -3,17 +3,9 @@
 :author: F. Voillat
 :date: 2021-02-24 Creation
 '''
-from .base import DBoard, DacSignal, DBoardPreferredDapiMode
+from .base import DBoard, DBoardPreferredDapiMode
 
 
-
-class DacSignalMb92(DacSignal):
-    DPA_VIRT = 0
-    DPA_REAP = 1
-    PHI = 2
-    DRAG = 3
-    PWM_OPENING = 4
-
 class Board92(DBoard):
     '''Class for MB-92 Dassym's board.
 
@@ -25,7 +17,7 @@ class Board92(DBoard):
     number = '92'
     '''Board type number (str)'''
     
-    DAC_SIGNAL = DacSignalMb92
+    
 
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
